@@ -1,5 +1,5 @@
 ##Areas of basic 2d shapes
-##Thomas B
+##TomTheCodingGuy
 import math
 
 def Square(side):
@@ -43,4 +43,10 @@ def Polygon(sides,sidelength,apothem):
 
 def Kite(height,width):
     area=(height*width)/2
+    return area
+
+def Pentagram(pentside,pentapothem,triheight):
+    triangles = (pentside*triheight/2)*5
+    pent = Polygon(5,pentside,pentapothem)
+    area = triangles + pent
     return area
\ No newline at end of file
